function [] = pickRectangleByDateRange(src, ~)
%PICKRECTANGLEBYDATERANGE Lets the user pick a rectangle by min and max message date.

global artoaGui artoaWorkspace;

%% Check for any active mode

if ~islogical(artoaGui.editTimeOfArrival.currentInteractionMode)
    errordlg('Another interaction mode is currently active. Please finish it first!', 'Interaction mode error!');
    return;
end

%% Check if polygon is already selected
if ~artoa.controller.edit.timeOfArrival.dropSelection()
    return;
end


%% Initialize variable
artoaGui.editTimeOfArrival.userSelection = {};
artoaWorkspace.editTimeOfArrival.userSelection = false(length(artoaWorkspace.toaData.toa), 1);

%% Initialize polygon
artoaGui.editTimeOfArrival.tmpPolygon = struct();
artoaGui.editTimeOfArrival.tmpPolygon.x = [];
% initialize y for the resulting rectangle
artoaGui.editTimeOfArrival.tmpPolygon.y = [ ...
    min(artoaWorkspace.toaData.toa); ...
    max(artoaWorkspace.toaData.toa); ...
    max(artoaWorkspace.toaData.toa); ...
    min(artoaWorkspace.toaData.toa) ...
    ];

%% Create line that will show the result
artoaGui.editTimeOfArrival.userSelection = line( ...
    NaN, NaN, 'Color', [0 0 0], 'LineStyle', '-' ...
);

%% Ask for min and max value
values = {'Minimum message date:', 'Maximum message date:'};
values = inputdlg(values);
values = str2double(values);

% validity check
if any(isnan(values)) || isempty(values)
    % force drop selection
    artoa.controller.edit.timeOfArrival.dropSelection(true);
    warndlg('One or more input values could not be converted to double. Please try again', 'Input error!');
    return;
end

artoaGui.editTimeOfArrival.tmpPolygon.x = [ ...
    values(1); ...
    values(1); ...
    values(2); ...
    values(2) ...
    ];

finishPolygon();

return

%% Helper functions


    function finishPolygon()
        % close the poligon by adding the first value as the last one
        if length(artoaGui.editTimeOfArrival.tmpPolygon.x) > 3 % a polygon can only be closed if there are more than three values
            x = [artoaGui.editTimeOfArrival.tmpPolygon.x; artoaGui.editTimeOfArrival.tmpPolygon.x(1)];
            y = [artoaGui.editTimeOfArrival.tmpPolygon.y; artoaGui.editTimeOfArrival.tmpPolygon.y(1)];
        else
            [artoaGui.editTimeOfArrival, artoaWorkspace.editTimeOfArrival] = artoa.controller.edit.clearSelection(artoaGui.editTimeOfArrival, artoaWorkspace.editTimeOfArrival);
            return;
        end
        % update the line
        set(artoaGui.editTimeOfArrival.userSelection, 'XData', x, 'YData', y);
        % store the selected points in the workspace for editing
        artoaWorkspace.editTimeOfArrival.userSelection = inpolygon( ...
            artoaWorkspace.toaData.toaDate, ...
            artoaWorkspace.toaData.toa, ...
            x, ...
            y ...
        );
    end

end

