function [ boolean ] = has_no_gps_but_iridium( p_profile )
%HAS_NO_GPS_BUT_IRIDIUM Checks if profile has iridium coordinates, but no gps.
%
%   Returns: True if iridium but no gps coordinates are available.
%            Displays a warning if parameters are wrong, but returns false!
%
%   Parameters:
%   p_profile:          The nemo profile that is being checked.

%% Initializing return variables
boolean = false;

%% Parameter check

if (~isstruct(p_profile))
    disp([mfilename ': Wrong parameter. Please check your input. Returning false!']);
end

%% Check if gps section and values are available
if (isfield(p_profile, 'SURFACE_GPS_DATA'))
    % check if the values are available
    gps_available = (~any(isnan(p_profile.SURFACE_GPS_DATA))) && ~isempty(p_profile.SURFACE_GPS_DATA);
else
    gps_available = false;
end

%% Check if iridium is available
if (isfield(p_profile, 'IRIDIUM_DATA') && ~isempty(p_profile.IRIDIUM_DATA))
    % check if the values are available
    % get indices of lat and lon
    index_lat = find(not(cellfun('isempty', ...
        strfind(p_profile.('IRIDIUM_DATA_FORMAT'), 'mean_lat') ...
        )));
    index_lon = find(not(cellfun('isempty', ...
        strfind(p_profile.('IRIDIUM_DATA_FORMAT'), 'mean_lon') ...
        )));
    boolean = (~isnan(p_profile.('IRIDIUM_DATA')(index_lat)) && ~isnan(p_profile.('IRIDIUM_DATA')(index_lon)));
    
    if (boolean && ~gps_available)
        boolean = true;
        return
    else
        boolean = false;
        return;
    end
else
    boolean = false;
    return;
end

end

